==> haskell-openpgp-asciiarmor-0.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openpgp-asciiarmor
version: 0.1
id: openpgp-asciiarmor-0.1-5JfiTLY0QNu7SZwvgPWVg8
key: openpgp-asciiarmor-0.1-5JfiTLY0QNu7SZwvgPWVg8
license: OtherLicense
copyright: 2012, Clint Adams
maintainer: Clint Adams <clint@debian.org>
homepage: http://floss.scru.org/openpgp-asciiarmor
synopsis: OpenPGP (RFC4880) ASCII Armor codec
description:
    OpenPGP (RFC4880) ASCII Armor codec
category: Codec, Data
author: Clint Adams
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types
hidden-modules: Data.Digest.CRC24
                Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
                Codec.Encryption.OpenPGP.ASCIIArmor.Utils
abi: 4616af96f5bb780ec9fe6972996db9df
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/openpgp-asciiarmor-0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/openpgp-asciiarmor-0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/openpgp-asciiarmor-0.1
hs-libraries: HSopenpgp-asciiarmor-0.1-5JfiTLY0QNu7SZwvgPWVg8
depends:
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
haddock-interfaces: /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock
haddock-html: /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openpgp-asciiarmor-0.1-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openpgp-asciiarmor
version: 0.1
id: openpgp-asciiarmor-0.1-Alp8PYDIsej9Y3uPSZRQCi
key: openpgp-asciiarmor-0.1-Alp8PYDIsej9Y3uPSZRQCi
license: OtherLicense
copyright: 2012, Clint Adams
maintainer: Clint Adams <clint@debian.org>
homepage: http://floss.scru.org/openpgp-asciiarmor
synopsis: OpenPGP (RFC4880) ASCII Armor codec
description:
    OpenPGP (RFC4880) ASCII Armor codec
category: Codec, Data
author: Clint Adams
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types
hidden-modules: Data.Digest.CRC24
                Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
                Codec.Encryption.OpenPGP.ASCIIArmor.Utils
abi: f12386700c18ac236859faeff36e701f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/openpgp-asciiarmor-0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/openpgp-asciiarmor-0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/openpgp-asciiarmor-0.1
hs-libraries: HSopenpgp-asciiarmor-0.1-Alp8PYDIsej9Y3uPSZRQCi
depends:
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
haddock-interfaces: /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock
haddock-html: /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
